==> r4ss_1.05.tar.gz: r4ss/man/update_r4ss_files.Rd <==
\name{update_r4ss_files}
\alias{update_r4ss_files}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Updates r4ss files to newest versions on web. }
\description{
  Sources files containing R functions r4ss package from the google code
  repository. These may often be newer than those available form CRAN
  mirrors.
}
\usage{
update_r4ss_files()  
}
%- maybe also 'usage' for other objects documented here.
% \arguments{
% }
% \details{
%   ~~ If necessary, more details than the description above ~~
% }
% \value{
%   ~Describe the value returned
%   If it is a LIST, use
%   \item{comp1 }{Description of 'comp1'}
%   \item{comp2 }{Description of 'comp2'}
%   ...
% }
% \references{ ~put references to the literature/web site here ~ }
\author{ Ian Taylor }
% \note{ ~~further notes~~ 

%  % ~Make other sections like Warning with \section{Warning }{....} ~
% }
% \seealso{
%   \code{\link{SS_parlines}}, \code{\link{SS_profile}}
% }
\examples{
\dontrun{
update_r4ss_files()
# [1] sourcing SS_changepars.R
# [1] sourcing SS_fitbiasramp.R
# [1] sourcing SS_parlines.R
# [1] sourcing SS_profile.R
# [1] sourcing SS_recdevs.R
# [1] sourcing SS_splitdat.R
# [1] sourcing SSv3_FishGraph.R
# [1] sourcing SSv3_output.R
# [1] sourcing SSv3_plotpars.R
# [1] sourcing SSv3_plots.R
# [1] sourcing lines.sel.R
# [1] sourcing movepars.R
# [1] sourcing selfit.R}
}
% % Add one or more standard keywords, see file 'KEYWORDS' in the
% % R documentation directory.
\keyword{ file }
% \keyword{ ~kwd2 }% __ONLY ONE__ keyword per line

==> r4ss_1.06.tar.gz: r4ss/man/update_r4ss_files.Rd <==
\name{update_r4ss_files}
\alias{update_r4ss_files}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Updates r4ss files to newest versions on web. }
\description{
  Sources files containing R functions r4ss package from the google code
  repository. These may often be newer than those available form CRAN
  mirrors.
}
\usage{
update_r4ss_files(trunk=T, branches=F)
}
\arguments{
  \item{trunk}{ Get files from trunk directory? Default=T.}
  \item{branches}{ Get files from some branches subdirectories? Default=F.}
}
% \details{
%   ~~ If necessary, more details than the description above ~~
% }
% \value{
%   ~Describe the value returned
%   If it is a LIST, use
%   \item{comp1 }{Description of 'comp1'}
%   \item{comp2 }{Description of 'comp2'}
%   ...
% }
% \references{ ~put references to the literature/web site here ~ }
\author{ Ian Taylor }
% \note{ ~~further notes~~

%  % ~Make other sections like Warning with \section{Warning }{....} ~
% }
% \seealso{
%   \code{\link{SS_parlines}}, \code{\link{SS_profile}}
% }
\examples{
\dontrun{
update_r4ss_files()
# [1] sourcing SS_changepars.R
# [1] sourcing SS_fitbiasramp.R
# [1] sourcing SS_parlines.R
# [1] sourcing SS_profile.R
# [1] sourcing SS_recdevs.R
# [1] sourcing SS_splitdat.R
# [1] sourcing SSv3_FishGraph.R
# [1] sourcing SSv3_output.R
# [1] sourcing SSv3_plotpars.R
# [1] sourcing SSv3_plots.R
# [1] sourcing lines.sel.R
# [1] sourcing movepars.R
# [1] sourcing selfit.R}
}
% % Add one or more standard keywords, see file 'KEYWORDS' in the
% % R documentation directory.
\keyword{ file }
% \keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
